@@ -1,6 +1,6 @@
-/***********************************************************************
+﻿/***********************************************************************
  *
- * Copyright (C) 2020 wereturtle
+ * Copyright (C) 2020-2021 wereturtle
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -397,7 +397,7 @@ void FindReplace::replaceAll()
         count++;
     }
 
-    d->statusLabel->setText(tr("%1 replacements").arg(count));
+    d->statusLabel->setText(tr("%Ln replacement(s)", "", count));
     d->editor->setFocus();
 }
 
@@ -565,4 +565,4 @@ void FindReplacePrivate::closeFindReplace()
     }
 }
 
-} // namepsace ghostwriter
+} // namespace ghostwriter
